================================
Nova-dpm specifications for Pike
================================

Template:

.. toctree::
   :maxdepth: 1

   Specification Template (Pike release) <template>

Specs implemented in Pike:

.. toctree::
   :glob:
   :maxdepth: 1

   implemented/*

Specs proposed / approved for Pike:

.. toctree::
   :glob:
   :maxdepth: 1

   approved/*
